Internal function that proposes parameter updates used in MCMC estimation of the BBMV model.
proposal_nclades_plus_3_pars(type = "Uniform", sensitivity, pars, n_clades)The type of proposal function, only 'Uniform' is available (the default).
A numeric vector specifying the width of the uniform proposal for each parameter.
The current parameters in the MCMC chain.
The number of clades under study.